import * as React from 'react';
import MuiThemeProvider from 'material-ui/styles/MuiThemeProvider';
import Paper from 'material-ui/Paper';
import RemoveRedEye from 'material-ui/svg-icons/image/remove-red-eye';
import DropDownMenu from 'material-ui/DropDownMenu';
import MenuItem from 'material-ui/MenuItem';
import Divider from 'material-ui/Divider';
import Dialog from 'material-ui/Dialog';
import FlatButton from 'material-ui/FlatButton';
import RaisedButton from 'material-ui/RaisedButton';
import TextField from 'material-ui/TextField';
import LinearProgress from 'material-ui/LinearProgress';
import {ItemSelector} from './ItemSelector';

const styles = {
};


export class CrawlerSelector extends React.Component<any, any> {
    constructor(props: any, context: any) {
        super(props, context)
        this.state = {
            crawlerType: 0,
            authOpen: false,
            isloading: false
        };
    }

    handleCrawlerChange = (event: any, index: any, value: any) => {
        if (value == 1) {
            this.setState({ crawlerType: value });
            return;
        }
        if (this.validateCrawlerType()) {
            this.setState({ crawlerType: value });
        } else {
            this.setState({ crawlerType: 0 });
        }
    }

    validateCrawlerType = () => {
        this.setState({ authOpen: true });
        return true;
    }

    handleAuthPopupOk = () => {
        this.setState({ isLoading: true })
        //this.setState({ authOpen: false });
    };
    handleAuthPopupCancle = () => {
        this.setState({ authOpen: false, crawlerType: 0, isLoading: false });
    };


    getAuthPopupContent = () => {
        switch (this.state.crawlerType) {
            case 2:
                return <WMIAuthPopup />;
            case 3:
                return <SNMPv2AuthPopup />;
            case 4:
                return <SNMPv3AuthPopup />;
            case 5:
                return <JMXAuthPopup />;
            default:
                return 'errrrrrr';
        }
    }

    showLoadingBar = () => {
        if (this.state.isLoading) {
            return <LinearProgress mode="indeterminate" style={{ marginTop: 30 }} />;
        }
    }

    render() {
        const actions = [
            <FlatButton
                label="Cancel"
                primary={true}
                onTouchTap={this.handleAuthPopupCancle}
            />,
            <FlatButton
                label="Submit"
                primary={true}
                onTouchTap={this.handleAuthPopupOk}
            />,
        ];

        return (

            <MuiThemeProvider >
                <div>
                    <Dialog
                        title="Connection information is required."
                        actions={actions}
                        modal={true}
                        open={this.state.authOpen}
                    >
                        {this.getAuthPopupContent()}
                        {this.showLoadingBar()}

                    </Dialog>

                    <Paper >
                        <DropDownMenu value={this.state.crawlerType} onChange={this.handleCrawlerChange} style={{ width: 200 }}>
                            <MenuItem value={1} primaryText="Protocol" />
                            <MenuItem value={2} primaryText="WMI" />
                            <MenuItem value={3} primaryText="SNMPv2c" />
                            <MenuItem value={4} primaryText="SNMPv3" />
                            <MenuItem value={5} primaryText="JMX" />
                        </DropDownMenu>

                        <Divider />

                        <div style={{ padding: 30 }}>
                            Crawler description....
                        </div>
                        <br />
                        <ItemSelector/>
                    </Paper>
                </div>
            </MuiThemeProvider>
        );
    }
}

export class SNMPv2AuthPopup extends React.Component<any, any> {
    constructor(props: any, context: any) {
        super(props, context)
        this.state = {
        };
    }


    render() {
        return (
            <MuiThemeProvider >
                <div>
                    FORM FOR SNMPV2C
                    <br />
                    <TextField
                        hintText="Community"
                        errorText="This field is required"
                    />
                </div>
            </MuiThemeProvider>
        );
    }
}

export class SNMPv3AuthPopup extends React.Component<any, any> {
    constructor(props: any, context: any) {
        super(props, context)
        this.state = {
        };
    }


    render() {
        return (
            <MuiThemeProvider >
                <div>
                    FORM FOR SNMPV3
                        <TextField
                        hintText="User"
                        errorText="This field is required"
                    />
                </div>
            </MuiThemeProvider>
        );
    }
}

export class WMIAuthPopup extends React.Component<any, any> {
    constructor(props: any, context: any) {
        super(props, context)
        this.state = {
        };
    }


    render() {
        return (
            <MuiThemeProvider >
                <div>
                    FORM FOR WMI
                </div>
            </MuiThemeProvider>
        );
    }
}

export class JMXAuthPopup extends React.Component<any, any> {
    constructor(props: any, context: any) {
        super(props, context)
        this.state = {
        };
    }


    render() {
        return (
            <MuiThemeProvider >
                <div>
                    FORM FOR JMX
                </div>
            </MuiThemeProvider>
        );
    }
}