import * as React from 'react';
import { OFRest } from '../../components/Rest';
import Dialog from 'material-ui/Dialog';
import FlatButton from 'material-ui/FlatButton';
import RaisedButton from 'material-ui/RaisedButton';
import { Card, CardActions, CardHeader, CardText } from 'material-ui/Card';
import * as Utils from '../../components/Utils';
import DropDownMenu from 'material-ui/DropDownMenu';
import MenuItem from 'material-ui/MenuItem';
import AppBar from 'material-ui/AppBar';
import Checkbox from 'material-ui/Checkbox';
import TextField from 'material-ui/TextField';
import { RadioButton, RadioButtonGroup } from 'material-ui/RadioButton';
import Paper from 'material-ui/Paper';
import {
    Table,
    TableBody,
    TableHeader,
    TableHeaderColumn,
    TableRow,
    TableRowColumn,
} from 'material-ui/Table';

const customContentStyle = {
    width: '90%',
    maxWidth: 'none',
};

export class SensorConfigPopup extends React.Component<any, any> {
    private tempList: any[];
    constructor(props: any, context: any) {
        super(props, context);
        this.state = {
            crawler: null,
            sensorItems: [],
            selectedItems: [],
            startConfirm: false,
        };
    }

    componentWillMount() {
        this.tempList = [];
    }

    handleClose = () => {
        this.props.onCancel();
    }

    handleConfirmCancel = () => {
        this.setState({
            startConfirm: false,
        });
    }

    handleCrawlerSelect = (c: any) => {
        //getting items by target&crawler type
        console.log("aaaaaaa");
        let os: OFRest = new OFRest("SensorItem", "List", c);
        var that: any = this;
        os.CallWithCB(function (json: any) {
            let list = JSON.parse(json.resultStr);
            console.log(list);
            that.setState({
                crawler: c,
                sensorItems: list,
            });
        });
        // os.Call().then(function (res) {
        //     return res.json();
        // }).then(function (json) {
        //     let list = JSON.parse(json.resultStr);
        //     console.log(list);
        //     that.setState({
        //         crawler: c,
        //         sensorItems: list,
        //     });
        // }).catch(function (err) {
        //     console.log(err);
        // });

    }

    handleSensorItemsSelect = (items: any) => {
        let temp = [];
        if (items === 'all') {
            this.tempList = this.state.sensorItems;
        } else {
            if (items.length > 0) {
                for (var i = 0; i < items.length; i++) {
                    temp[i] = this.state.sensorItems[items[i]];
                }
            }
            this.tempList = temp;
        }

    }

    handleSubmit = () => {
        if (this.tempList.length === 0) {
            alert("You should choose at least one sensor.");
        } else {
            this.setState({
                startConfirm: true,
                selectedItems: this.tempList
            });
        }
    }

    render() {
        const actions = [
            <FlatButton
                label="Cancel"
                primary={true}
                onTouchTap={this.handleClose}
            />,
            <RaisedButton
                label="Submit"
                primary={true}
                onTouchTap={this.handleSubmit}
            />,
        ];

        return (
            <div>
                <Dialog
                    title="Sensor Configuration"
                    actions={actions}
                    modal={true}
                    contentStyle={customContentStyle}
                    open={this.props.open}
                >

                    <Card>
                        <CardHeader
                            title={this.props.target.vendorName}
                            subtitle={Utils.int2ip(this.props.target.ip)}
                            actAsExpander={true}
                            showExpandableButton={true}
                        />
                        <CardText expandable={true}>
                            <div>Discovered At : {this.props.target.createDate}</div>
                            <div>Target Type : {this.props.target.targetType}</div>
                            <div>Kind : {this.props.target.kinds}</div>
                            <div>Name : {this.props.target.vendorName}</div>
                            <div>Version : {this.props.target.version}</div>
                            <div>Port : {this.props.target.port}</div>
                            <div>Port Type : {this.props.target.portType}</div>
                        </CardText>
                    </Card>

                    <Card>
                        <CrawlerSelector target={this.props.target} onChange={this.handleCrawlerSelect} />
                    </Card>
                    <Card>
                        <SensorItemSelector items={this.state.sensorItems} onChange={this.handleSensorItemsSelect} />
                    </Card>
                </Dialog>
                <ConfirmPopup open={this.state.startConfirm} onCancel={this.handleConfirmCancel}
                    target={this.props.target}
                    crawler={this.state.crawler}
                    items={this.state.selectedItems} />

            </div>
        );
    }
}


export class CrawlerSelector extends React.Component<any, any> {
    constructor(props: any, context: any) {
        super(props, context);
        this.state = {
            value: -1,
            crawlers: [],
            authOpen: false,
            authInputs: [],
        };
    }

    componentWillMount() {
        let os: OFRest = new OFRest("Crawler", "List", null);
        var that: any = this;
        os.CallWithCB(function (json: any) {
            let list = JSON.parse(json.resultStr);
            that.setState({
                crawlers: list,
            });
        })
        // os.Call().then(function (res) {
        //     return res.json();
        // }).then(function (json) {
        //     let list = JSON.parse(json.resultStr);
        //     that.setState({
        //         crawlers: list,
        //     });
        // }).catch(function (err) {
        //     console.log(err);
        // });
    }

    handleCrawlerChange = (event: any, index: any, v: number) => {
        this.setState({
            value: v,
        });
        if (v === -1) {
            return;
        }
        let selectedCrawler = this.state.crawlers[v];
        this.props.onChange(selectedCrawler);
        this.checkAuth(selectedCrawler);
    }

    checkAuth = (c: any) => {
        //Todo. validate auth
        this.setState({
            authOpen: false,
        });
        let os: OFRest = new OFRest("CrawlerinputitemMapping", "List", c);
        var that: any = this;
        os.CallWithCB(function (json: any) {
            var list = JSON.parse(json.resultStr);
            that.setState({
                authInputs: list,
            });
        });
        // os.Call().then(function (res) {
        //     return res.json();
        // }).then(function (json) {

        //     var list = JSON.parse(json.resultStr);
        //     that.setState({
        //         authInputs: list,
        //     });
        // }).catch(function (err) {
        //     console.log(err);
        // });
    }


    getCrawlerTitle() {
        if (this.state.value === -1) {
            return "";
        }
        var c = this.state.crawlers[this.state.value];
        return "[" + c.crawlerType + "] " + c.description;
    }

    renderAuthRequester = () => {
        if (this.state.authInputs.length === 0) {
            return <div></div>;
        }
        return <div> Connection Info.  {
            this.state.authInputs.map((data: any, index: number) => {
                return <div key={index}>{this.renderInputs(data)}</div>;
            })
        }</div>;
    }

    handleTestAuth = () => {

    }

    renderInputs = (data: any) => {
        let input = data.crawlerInputItem;
        if (input.dataType === "String") {
            return <div><TextField
                hintText={input.description}
                floatingLabelText={input.name}
                underlineShow={true}
                value={this.state.email}
                onChange={(e, newValue) => this.setState({ email: newValue })}
            />
            </div>;
        }
        else if (input.dataType === "Select") {
            let values = input.description.split('||');
            let radios = Array();
            for (var i = 0; i < values.length; i++) {
                radios.push(<RadioButton key={i} value={i} label={values[i]} />);
            }
            return <div>
                <RadioButtonGroup name={input.name} defaultSelected="not_light">
                    {radios}
                </RadioButtonGroup>
            </div>;
        }
    }

    handleExpand = (b: boolean) => {
        this.setState({
            authOpen: b,
        });
    }

    render() {
        return (
            <div>
                <DropDownMenu value={this.state.value} onChange={this.handleCrawlerChange} style={{ width: 300 }}>
                    <MenuItem value={-1} primaryText="Choose a Crawler type" />
                    {this.state.crawlers.map((crawler: any, index: number) => {
                        return (<MenuItem
                            value={index}
                            primaryText={crawler.name}
                            key={index}
                        />);
                    })}

                </DropDownMenu>
                <Card expanded={this.state.authOpen} onExpandChange={this.handleExpand.bind(this)}>
                    <CardHeader
                        title={this.getCrawlerTitle()}
                        subtitle=''
                        actAsExpander={true}
                        showExpandableButton={true}
                    />
                    <CardText expandable={true} >
                        {this.renderAuthRequester()}
                    </CardText>
                </Card>

            </div>
        );
    }
}


export class SensorItemSelector extends React.Component<any, any> {

    constructor(props: any, context: any) {
        super(props, context);
        this.state = {
            selected: []
        };
    }


    isSelected = (index: any) => {
        return this.state.selected.indexOf(index) !== -1;
    }

    handleRowSelection = (selectedRows: any) => {
        this.setState({
            selected: selectedRows,
        });
        this.props.onChange(selectedRows);
    }

    render() {
        return (
            <div style={{ height: 320, overflow: 'auto' }}>
                <Table onRowSelection={this.handleRowSelection} multiSelectable={true}>
                    <TableHeader>
                        <TableRow>
                            <TableHeaderColumn>Category</TableHeaderColumn>
                            <TableHeaderColumn>Name</TableHeaderColumn>
                            <TableHeaderColumn>Description</TableHeaderColumn>
                        </TableRow>
                    </TableHeader>
                    <TableBody deselectOnClickaway={false}>

                        {this.props.items.map((row: any, index: number) => (
                            <TableRow key={index} selected={this.isSelected(index)}>
                                <TableRowColumn>{row.category}</TableRowColumn>
                                <TableRowColumn>{row.name}</TableRowColumn>
                                <TableRowColumn>{row.description}</TableRowColumn>
                            </TableRow>
                        ))}
                    </TableBody>
                </Table>
            </div>
        );
    }
}


export class ConfirmPopup extends React.Component<any, any> {
    constructor(props: any, context: any) {
        super(props, context);
        this.state = {
        };
    }

    handleClose = () => {
        this.props.onCancel();
    }


    handleConfirm = () => {
        if (this.props.target === null ||
            this.props.crawler === null) {
            alert("err");
            return;
        }
        let sensor: any;
        sensor = {
            "target": this.props.target,
            "notification": "",
            "interval": 10,
            "crawler": this.props.crawler,
        }

        let os: OFRest = new OFRest("Sensor", "Create", sensor);
        var that: any = this;
        os.CallWithCB(function (json: any) {
            let retSensor = JSON.parse(json.resultStr);
            let smlist: any[] = [];
            that.props.items.map((data: any, index: number) => {
                var sm: any;
                sm = {
                    "sensor": retSensor,
                    "sensorItem": data,
                }
                smlist.push(sm);
            });

            let os2: OFRest = new OFRest("SensorItemMapping", "CreateAll", smlist);

            os2.CallWithCB(function (json2: any) {
                console.log(json2);
            });

        });

        // this.props.items
        // let os: OFRest = new OFRest("SensorItem", "List", JSON.stringify(c));
        // var that: any = this;
        // os.Call().then(function (res) {
        //     return res.json();
        // }).then(function (json) {
        //     let list = JSON.parse(json.resultStr);
        //     console.log(list);
        //     that.setState({
        //         crawler: c,
        //         sensorItems: list,
        //     });
        // }).catch(function (err) {
        //     console.log(err);
        // });
    }

    showInfo = () => {
        if (this.props.target === null || this.props.crawler === null) {
            return <div></div>;
        }
        return <div>
            <div>TARGET : {this.props.target.vendorName}</div>
            <div>CRAWLER : {this.props.crawler.name}</div>
            <br />
            <div>Sensor Items</div>
        </div>;
    }

    render() {
        const actions = [
            <FlatButton
                label="Cancel"
                primary={true}
                onTouchTap={this.handleClose}
            />,
            <RaisedButton
                label="Confirm"
                primary={true}
                onTouchTap={this.handleConfirm}
            />,
        ];

        return (
            <Dialog
                title="Confirm sensor configuration"
                actions={actions}
                modal={true}
                open={this.props.open}
            >
                <div>
                    {this.showInfo()}
                    {this.props.items.map((data: any, index: number) => {
                        return <Paper key={index}>{data.id}. {data.name}-{data.description}</Paper>;
                    })}
                </div>
            </Dialog>
        );
    }
}